Security Advisories (9)
CVE-2020-11022 (2020-04-29)

In jQuery versions greater than or equal to 1.2 and before 3.5.0, passing HTML from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2020-11023 (2020-04-29)

In jQuery versions greater than or equal to 1.0.3 and before 3.5.0, passing HTML containing <option> elements from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2019-11358 (2019-04-20)

jQuery before 3.4.0, as used in Drupal, Backdrop CMS, and other products, mishandles jQuery.extend(true, {}, ...) because of Object.prototype pollution. If an unsanitized source object contained an enumerable __proto__ property, it could extend the native Object.prototype.

CVE-2015-9251 (2018-01-18)

jQuery before 3.0.0 is vulnerable to Cross-site Scripting (XSS) attacks when a cross-domain Ajax request is performed without the dataType option, causing text/javascript responses to be executed.

CVE-2011-4969 (2013-03-08)

Cross-site scripting (XSS) vulnerability in jQuery before 1.6.3, when using location.hash to select elements, allows remote attackers to inject arbitrary web script or HTML via a crafted tag.

CVE-2012-6708 (2018-01-18)

jQuery before 1.9.0 is vulnerable to Cross-site Scripting (XSS) attacks. The jQuery(strInput) function does not differentiate selectors from HTML in a reliable fashion. In vulnerable versions, jQuery determined whether the input was HTML by looking for the '<' character anywhere in the string, giving attackers more flexibility when attempting to construct a malicious payload. In fixed versions, jQuery only deems the input to be HTML if it explicitly starts with the '<' character, limiting exploitability only to attackers who can control the beginning of a string, which is far less common.

CVE-2020-7656 (2020-05-19)

jquery prior to 1.9.0 allows Cross-site Scripting attacks via the load method. The load method fails to recognize and remove "<script>" HTML tags that contain a whitespace character, i.e: "</script >", which results in the enclosed script logic to be executed.

CVE-2019-5428

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

CVE-2014-6071 (2018-01-16)

jQuery 1.4.2 allows remote attackers to conduct cross-site scripting (XSS) attacks via vectors related to use of the text method inside after.

NAME

Sidef::Types::Set::Bag

DESCRIPTION

This class implements ...

SYNOPSIS

var obj = Bag(...)

INHERITS

Inherits methods from:

* Sidef::Types::Set::Set

METHODS

&

a & b

Returns the

Aliases: , and, intersection

+

a + b

Returns the

Aliases: concat

-

a - b

Returns the

Aliases: , sub, diff, difference

...

a ... b

Returns the

Aliases: to_list

<<

a << b

Returns the

Aliases: add, push, append

^

a ^ b

Returns the

Aliases: xor, symdiff, symmetric_difference

|

a | b

Returns the

Aliases: , or, union

a ∋ b

Returns the

Aliases: has, exists, has_key, haskey, contain, include, contains, includes

a ∌ b

Returns the

a ≠ b

Returns the

Aliases: !=, ne

a ≡ b

Returns the

Aliases: ==, eq

a ≤ b

Returns the

Aliases: , <=, is_subset

a ≥ b

Returns the

Aliases: , >=, is_superset

add_kv

Bag.add_kv()

Returns the

Aliases: push_kv, add_pair, append_kv, push_pair, append_pair

add_kvs

Bag.add_kvs()

Returns the

Aliases: push_kvs, add_pairs, append_kvs, push_pairs, append_pairs

clone

Bag.clone()

Returns the

collect

Bag.collect()

Returns the

contains_all

Bag.contains_all()

Returns the

count_by

Bag.count_by()

Returns the

delete

Bag.delete()

Returns the

Aliases: remove, discard

delete_all

Bag.delete_all()

Returns the

Aliases: remove_all, discard_all

delete_first_if

Bag.delete_first_if()

Returns the

delete_if

Bag.delete_if()

Returns the

delete_key

Bag.delete_key()

Returns the

Aliases: remove_key, discard_key

dump

Bag.dump()

Returns the

each

Bag.each()

Returns the

each_2d

Bag.each_2d()

Returns the

each_kv

Bag.each_kv()

Returns the

elems

Bag.elems()

Returns the

Aliases: keys_len

freq

Bag.freq()

Returns the

get

Bag.get()

Returns the

Aliases: count

grep

Bag.grep()

Returns the

Aliases: select

grep_2d

Bag.grep_2d()

Returns the

grep_kv

Bag.grep_kv()

Returns the

iter

Bag.iter()

Returns the

join

Bag.join()

Returns the

keys

Bag.keys()

Returns the

kv

Bag.kv()

Returns the

Aliases: pairs

len

Bag.len()

Returns the

Aliases: size, length

map

Bag.map()

Returns the

map_2d

Bag.map_2d()

Returns the

map_kv

Bag.map_kv()

Returns the

max

Bag.max()

Returns the

max_by

Bag.max_by()

Returns the

min

Bag.min()

Returns the

min_by

Bag.min_by()

Returns the

new

Bag.new()

Returns the

Aliases: call

pop

Bag.pop()

Returns the

set_kv

Bag.set_kv()

Returns the

Aliases: update_kv, update_pair, replace_pair

set_kvs

Bag.set_kvs()

Returns the

Aliases: update_kvs, update_pairs, replace_pairs

shift

Bag.shift()

Returns the

sort

Bag.sort()

Returns the

sort_by

Bag.sort_by()

Returns the

to_a

Bag.to_a()

Returns the

Aliases: expand, to_array

to_bag

Bag.to_bag()

Returns the

top

Bag.top()

Returns the

Aliases: most_common

to_set

Bag.to_set()

Returns the

uniq

Bag.uniq()

Returns the

Aliases: unique

values

Bag.values()

Returns the